extract_enm: Extracts summary statistics from a raster file based on the...

View source: R/extract_enm.R

extract_enmR Documentation

Extracts summary statistics from a raster file based on the boundaries of a shapefile

Description

The function extract_enm

Usage

extract_enm(enm, geoshape, id0, id, th, save.plots = FALSE)

Arguments

enm

input raster data (usually a species distribution model, SDM)

geoshape

input shapefile with boundaries of geometries to summarize the raster data for

id0

part of 'geoshape@data' that holds the names of the geopolitical units to focus on (polygons of interest)

id

subset in geoshape identifier table to iterate through: a vector of names, may need to match this to a particular part of geoshape with id0

th

threshold of suitability used to calculate RSA. If not provided, the RSA is not calculated.

save.plots

save the density plots of points for each id iterated across (default is FALSE)? If so, the results are stored as a second element in the list [[2]] or $plots

Value

Dataframe (tibble) that contains columns that include


ieco-lab/slfrsk documentation built on Aug. 18, 2022, 10:44 a.m.