| extract_enm | R Documentation |
The function extract_enm
extract_enm(enm, geoshape, id0, id, th, save.plots = FALSE)
enm |
input raster data (usually a species distribution model, SDM) |
geoshape |
input shapefile with boundaries of geometries to summarize the raster data for |
id0 |
part of |
id |
subset in |
th |
threshold of suitability used to calculate RSA. If not provided, the RSA is not calculated. |
save.plots |
save the density plots of points for each |
Dataframe (tibble) that contains columns that include
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.